summaryrefslogtreecommitdiffstats
path: root/net/http/http_network_layer.h
diff options
context:
space:
mode:
authormbelshe@chromium.org <mbelshe@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-02-08 20:37:30 +0000
committermbelshe@chromium.org <mbelshe@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-02-08 20:37:30 +0000
commit955fc2e75864c1202c399d75c2351f01fba0a9a0 (patch)
treeeed044f5b961a2c9c4ec319c50e76bda09cb670f /net/http/http_network_layer.h
parent177002925b7152b6eafe92912fe922eb823d21c6 (diff)
downloadchromium_src-955fc2e75864c1202c399d75c2351f01fba0a9a0.zip
chromium_src-955fc2e75864c1202c399d75c2351f01fba0a9a0.tar.gz
chromium_src-955fc2e75864c1202c399d75c2351f01fba0a9a0.tar.bz2
The great Flip -> Spdy rename.
BUG=30747 TEST=none Review URL: http://codereview.chromium.org/580009 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@38386 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/http/http_network_layer.h')
-rw-r--r--net/http/http_network_layer.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/net/http/http_network_layer.h b/net/http/http_network_layer.h
index 38c10c7..3050298 100644
--- a/net/http/http_network_layer.h
+++ b/net/http/http_network_layer.h
@@ -14,12 +14,12 @@
namespace net {
class ClientSocketFactory;
-class FlipSessionPool;
class HostResolver;
class HttpNetworkSession;
class NetworkChangeNotifier;
class ProxyInfo;
class ProxyService;
+class SpdySessionPool;
class SSLConfigService;
class HttpNetworkLayer : public HttpTransactionFactory {
@@ -56,13 +56,13 @@ class HttpNetworkLayer : public HttpTransactionFactory {
virtual HttpNetworkSession* GetSession();
virtual void Suspend(bool suspend);
// Enable the flip protocol.
// Without calling this function, FLIP is disabled. The mode can be:
// "" : (default) SSL and compression are enabled.
// "no-ssl" : disables SSL.
// "no-compress" : disables compression.
// "none" : disables both SSL and compression.
- static void EnableFlip(const std::string& mode);
+ static void EnableSpdy(const std::string& mode);
private:
// The factory we will use to create network sockets.
@@ -79,10 +79,10 @@ class HttpNetworkLayer : public HttpTransactionFactory {
scoped_refptr<SSLConfigService> ssl_config_service_;
scoped_refptr<HttpNetworkSession> session_;
- scoped_refptr<FlipSessionPool> flip_session_pool_;
+ scoped_refptr<SpdySessionPool> spdy_session_pool_;
bool suspended_;
- static bool force_flip_;
+ static bool force_spdy_;
};
} // namespace net
@@ -56,13 +56,13 @@ class HttpNetworkLayer : public HttpTransactionFactory {
virtual HttpNetworkSession* GetSession();
virtual void Suspend(bool suspend);
- // Enable the flip protocol.
- // Without calling this function, FLIP is disabled. The mode can be:
+ // Enable the spdy protocol.
+ // Without calling this function, SPDY is disabled. The mode can be:
// "" : (default) SSL and compression are enabled.
// "no-ssl" : disables SSL.